@@ -166,7 +166,8 @@ export const headerbarModel = () => ({
                                 editor.mod.documentTemplate.documentStyles,
                                 editor.getDoc({changes: 'acceptAllNoInsertions'}),
                                 editor.mod.db.bibDB,
-                                editor.mod.db.imageDB
+                                editor.mod.db.imageDB,
+                                editor.docInfo.updated
                             )
                             exporter.init()
                         })
@@ -185,7 +186,8 @@ export const headerbarModel = () => ({
                                 editor.mod.documentTemplate.documentStyles,
                                 editor.getDoc({changes: 'acceptAllNoInsertions'}),
                                 editor.mod.db.bibDB,
-                                editor.mod.db.imageDB
+                                editor.mod.db.imageDB,
+                                editor.docInfo.updated
                             )
                             exporter.init()
                         })
@@ -201,7 +203,8 @@ export const headerbarModel = () => ({
                             const exporter = new LatexExporter(
                                 editor.getDoc({changes: 'acceptAllNoInsertions'}),
                                 editor.mod.db.bibDB,
-                                editor.mod.db.imageDB
+                                editor.mod.db.imageDB,
+                                editor.docInfo.updated
                             )
                             exporter.init()
                         })
@@ -218,7 +221,8 @@ export const headerbarModel = () => ({
                                 editor.getDoc({changes: 'acceptAllNoInsertions'}),
                                 editor.mod.db.bibDB,
                                 editor.mod.db.imageDB,
-                                editor.app.csl
+                                editor.app.csl,
+                                editor.docInfo.updated
                             )
                             exporter.init()
                         })
