@@ -12,13 +12,18 @@ import {DOMExporter} from "../tools/dom_export"
 
 export class EpubExporter extends DOMExporter {
 
-    constructor(schema, csl, documentStyles, doc, bibDB, imageDB) {
+    constructor(schema, csl, documentStyles, doc, bibDB, imageDB, updated) {
         super(schema, csl, documentStyles)
         this.doc = doc
         this.bibDB = bibDB
         this.imageDB = imageDB
+        this.updated = updated
+
         this.shortLang = this.doc.settings.language.split('-')[0]
         this.lang = this.doc.settings.language
+
+        this.outputList = []
+        this.includeZips = []
     }
 
     init() {
@@ -77,7 +82,7 @@ export class EpubExporter extends DOMExporter {
 
         const containerCode = containerTemplate({})
 
-        const timestamp = getTimestamp()
+        const timestamp = getTimestamp(this.updated)
 
 
         const authors = this.docContents.content.reduce(
@@ -122,7 +127,7 @@ export class EpubExporter extends DOMExporter {
             keywords,
             idType: 'fidus',
             id: this.doc.id,
-            date: timestamp.slice(0, 10), // TODO: the date should probably be the original document creation date instead
+            date: timestamp.slice(0, 10),
             modified: timestamp,
             styleSheets: this.styleSheets,
             math,
@@ -144,7 +149,7 @@ export class EpubExporter extends DOMExporter {
             contentItems
         })
 
-        const outputList = [{
+        this.outputList.push({
             filename: 'META-INF/container.xml',
             contents: containerCode
         }, {
@@ -159,10 +164,10 @@ export class EpubExporter extends DOMExporter {
         }, {
             filename: 'EPUB/document.xhtml',
             contents: xhtmlCode
-        }]
+        })
 
         this.styleSheets.forEach(styleSheet => {
-            outputList.push({
+            this.outputList.push({
                 filename: 'EPUB/' + styleSheet.filename,
                 contents: styleSheet.contents
             })
@@ -180,23 +185,30 @@ export class EpubExporter extends DOMExporter {
             })
         })
 
-        const includeZips = []
         if (math) {
-            includeZips.push({
+            this.includeZips.push({
                 'directory': 'EPUB',
                 'url': `${settings_STATIC_URL}zip/mathlive_style.zip?v=${transpile_VERSION}`
             })
         }
+        return this.createZip()
+    }
+
+    createZip() {
         const zipper = new ZipFileCreator(
-            outputList,
+            this.outputList,
             this.binaryFiles,
-            includeZips,
-            'application/epub+zip'
+            this.includeZips,
+            'application/epub+zip',
+            this.updated
         )
 
-        zipper.init().then(
-            blob => download(blob, createSlug(title) + '.epub', 'application/epub+zip')
+        return zipper.init().then(
+            blob => this.download(blob)
         )
+    }
 
+    download(blob) {
+        return download(blob, createSlug(this.doc.title) + '.epub', 'application/epub+zip')
     }
 }
